@@ -3,12 +3,13 @@ package Lemonldap::NG::Common::Logger::Syslog;
 use strict;
 use Sys::Syslog qw(:standard);
 
-our $VERSION = '2.0.15';
+our $VERSION = '2.18.0';
 
 sub new {
     my ( $class, $conf, %args ) = @_;
     my $level = $conf->{logLevel} || 'info';
     my $self  = bless {}, $class;
+    our $done;
     if ( $args{user} ) {
         $self->{facility} = $conf->{userSyslogFacility} || 'auth';
         $self->{options}  = $conf->{userSyslogOptions}  || 'cons,pid,ndelay';
@@ -17,7 +18,14 @@ sub new {
         $self->{facility} = $conf->{syslogFacility} || 'daemon';
         $self->{options}  = $conf->{syslogOptions}  || 'cons,pid,ndelay';
     }
-    eval { openlog( 'LLNG', $self->{options}, $self->{facility} ) };
+    # Avoid to launch openlog multiple times, to prevent mech degradation from native to unix
+    # See also https://gitlab.ow2.org/lemonldap-ng/lemonldap-ng/-/issues/2771
+    unless ($done) {
+        eval {
+            openlog( 'LLNG', $self->{options}, $self->{facility} );
+            $done = 1;
+        };
+    }
     no warnings 'redefine';
     my $show = 1;
 
